@@ -28,6 +28,8 @@
  *
  * #SnapdApp is an opaque data structure and can only be accessed
  * using the provided functions.
+ *
+ * Since: 1.0
  */
 
 struct _SnapdApp
@@ -37,6 +39,7 @@ struct _SnapdApp
     SnapdDaemonType daemon_type;
     gchar *name;
     gchar **aliases;
+    gchar *desktop_file;
 };
 
 enum
@@ -44,6 +47,7 @@ enum
     PROP_NAME = 1,
     PROP_ALIASES,
     PROP_DAEMON_TYPE,
+    PROP_DESKTOP_FILE,
     PROP_LAST
 };
 
@@ -56,6 +60,8 @@ G_DEFINE_TYPE (SnapdApp, snapd_app, G_TYPE_OBJECT)
  * Get the name of this app.
  *
  * Returns: a name.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_app_get_name (SnapdApp *app)
@@ -71,6 +77,8 @@ snapd_app_get_name (SnapdApp *app)
  * Get the aliases for this app.
  *
  * Returns: (transfer none) (array zero-terminated=1): the alias names.
+ *
+ * Since: 1.7
  */
 gchar **
 snapd_app_get_aliases (SnapdApp *app)
@@ -85,7 +93,9 @@ snapd_app_get_aliases (SnapdApp *app)
  *
  * Get the daemon type for this app.
  *
- * Returns: the daemon type.
+ * Returns: (allow-none): the daemon type or %NULL.
+ *
+ * Since: 1.9
  */
 SnapdDaemonType
 snapd_app_get_daemon_type (SnapdApp *app)
@@ -94,6 +104,23 @@ snapd_app_get_daemon_type (SnapdApp *app)
     return app->daemon_type;
 }
 
+/**
+ * snapd_app_get_desktop_file:
+ * @app: a #SnapdApp.
+ *
+ * Get the path to the desktop file for this app.
+ *
+ * Returns: (allow-none): a path or %NULL.
+ *
+ * Since: 1.14
+ */
+const gchar *
+snapd_app_get_desktop_file (SnapdApp *app)
+{
+    g_return_val_if_fail (SNAPD_IS_APP (app), NULL);
+    return app->desktop_file;
+}
+
 static void
 snapd_app_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
@@ -111,6 +138,10 @@ snapd_app_set_property (GObject *object, guint prop_id, const GValue *value, GPa
     case PROP_DAEMON_TYPE:
         app->daemon_type = g_value_get_enum (value);
         break;
+    case PROP_DESKTOP_FILE:
+        g_free (app->desktop_file);
+        app->desktop_file = g_strdup (g_value_get_string (value));
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -132,6 +163,9 @@ snapd_app_get_property (GObject *object, guint prop_id, GValue *value, GParamSpe
     case PROP_DAEMON_TYPE:
         g_value_set_enum (value, app->daemon_type);
         break;
+    case PROP_DESKTOP_FILE:
+        g_value_set_string (value, app->desktop_file);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -145,6 +179,7 @@ snapd_app_finalize (GObject *object)
 
     g_clear_pointer (&app->name, g_free);
     g_clear_pointer (&app->aliases, g_strfreev);
+    g_clear_pointer (&app->desktop_file, g_free);
 }
 
 static void
@@ -177,6 +212,13 @@ snapd_app_class_init (SnapdAppClass *klass)
                                                         "Daemon type",
                                                         SNAPD_TYPE_DAEMON_TYPE, SNAPD_DAEMON_TYPE_UNKNOWN,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_DESKTOP_FILE,
+                                     g_param_spec_string ("desktop-file",
+                                                          "desktop-file",
+                                                          "App desktop file path",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 static void
