@@ -18,6 +18,7 @@
 #include <snapd-glib/snapd-auth-data.h>
 #include <snapd-glib/snapd-client.h>
 #include <snapd-glib/snapd-connection.h>
+#include <snapd-glib/snapd-enum-types.h>
 #include <snapd-glib/snapd-error.h>
 #include <snapd-glib/snapd-icon.h>
 #include <snapd-glib/snapd-login.h>
@@ -29,6 +30,7 @@
 #include <snapd-glib/snapd-system-information.h>
 #include <snapd-glib/snapd-task.h>
 #include <snapd-glib/snapd-user-information.h>
+#include <snapd-glib/snapd-version.h>
 
 #undef __SNAPD_GLIB_INSIDE__
 
