@@ -30,6 +30,8 @@
  *
  * #SnapdPlug is an opaque data structure and can only be accessed
  * using the provided functions.
+ *
+ * Since: 1.0
  */
 
 struct _SnapdPlug
@@ -64,6 +66,8 @@ G_DEFINE_TYPE (SnapdPlug, snapd_plug, G_TYPE_OBJECT)
  * Get the name of this plug.
  *
  * Returns: a name.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_plug_get_name (SnapdPlug *plug)
@@ -79,6 +83,8 @@ snapd_plug_get_name (SnapdPlug *plug)
  * Get the snap this plug is on.
  *
  * Returns: a snap name.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_plug_get_snap (SnapdPlug *plug)
@@ -94,6 +100,8 @@ snapd_plug_get_snap (SnapdPlug *plug)
  * Get the name of the interface this plug provides.
  *
  * Returns: an interface name.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_plug_get_interface (SnapdPlug *plug)
@@ -110,6 +118,8 @@ snapd_plug_get_interface (SnapdPlug *plug)
  * Get the names of the attributes this plug has.
  *
  * Returns: (transfer full) (array zero-terminated=1): a string array of attribute names. Free with g_strfreev().
+ *
+ * Since: 1.3
  */
 gchar **
 snapd_plug_get_attribute_names (SnapdPlug *plug, guint *length)
@@ -123,7 +133,7 @@ snapd_plug_get_attribute_names (SnapdPlug *plug, guint *length)
 
     g_hash_table_iter_init (&iter, plug->attributes);
     size = g_hash_table_size (plug->attributes);
-    names = malloc (sizeof (gchar *) * (size + 1));
+    names = g_malloc (sizeof (gchar *) * (size + 1));
     for (i = 0; g_hash_table_iter_next (&iter, &name, NULL); i++)
         names[i] = g_strdup (name);
     names[i] = NULL;
@@ -141,6 +151,8 @@ snapd_plug_get_attribute_names (SnapdPlug *plug, guint *length)
  * Check if this plug has an attribute.
  *
  * Returns: %TRUE if this attribute exists.
+ *
+ * Since: 1.3
  */
 gboolean
 snapd_plug_has_attribute (SnapdPlug *plug, const gchar *name)
@@ -157,6 +169,8 @@ snapd_plug_has_attribute (SnapdPlug *plug, const gchar *name)
  * Get an attribute for this interface.
  *
  * Returns: (transfer none) (allow-none): an attribute value or %NULL if not set.
+ *
+ * Since: 1.3
  */
 GVariant *
 snapd_plug_get_attribute (SnapdPlug *plug, const gchar *name)
@@ -172,6 +186,8 @@ snapd_plug_get_attribute (SnapdPlug *plug, const gchar *name)
  * Get a human readable label for this plug.
  *
  * Returns: a label.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_plug_get_label (SnapdPlug *plug)
@@ -187,6 +203,8 @@ snapd_plug_get_label (SnapdPlug *plug)
  * Get the connections being made with this plug.
  *
  * Returns: (transfer none) (element-type SnapdConnection): an array of #SnapdConnection.
+ *
+ * Since: 1.0
  */
 GPtrArray *
 snapd_plug_get_connections (SnapdPlug *plug)
@@ -273,8 +291,7 @@ snapd_plug_finalize (GObject *object)
     g_clear_pointer (&plug->interface, g_free);
     g_clear_pointer (&plug->attributes, g_hash_table_unref);
     g_clear_pointer (&plug->label, g_free);
-    if (plug->connections != NULL)
-        g_clear_pointer (&plug->connections, g_ptr_array_unref);
+    g_clear_pointer (&plug->connections, g_ptr_array_unref);
 }
 
 static void
