@@ -9,8 +9,6 @@
 
 #include "config.h"
 
-#define SNAPD_BUY_SUPPORT
-
 #include "snapd-snap.h"
 #include "snapd-enum-types.h"
 
@@ -29,6 +27,8 @@
  *
  * #SnapdSnap is an opaque data structure and can only be accessed
  * using the provided functions.
+ *
+ * Since: 1.0
  */
 
 struct _SnapdSnap
@@ -48,6 +48,7 @@ struct _SnapdSnap
     GDateTime *install_date;
     gint64 installed_size;
     gboolean jailmode;
+    gchar *license;
     gchar *name;
     GPtrArray *prices;
     gboolean private;
@@ -55,6 +56,7 @@ struct _SnapdSnap
     GPtrArray *screenshots;
     SnapdSnapStatus status;
     gchar *summary;
+    gchar *title;
     gchar *tracking_channel;
     gboolean trymode;
     SnapdSnapType snap_type;
@@ -87,6 +89,8 @@ enum
     PROP_SNAP_TYPE,
     PROP_VERSION,
     PROP_TRACKING_CHANNEL,
+    PROP_TITLE,
+    PROP_LICENSE,
     PROP_LAST
 };
 
@@ -99,6 +103,8 @@ G_DEFINE_TYPE (SnapdSnap, snapd_snap, G_TYPE_OBJECT)
  * Get the apps this snap provides.
  *
  * Returns: (transfer none) (element-type SnapdApp): an array of #SnapdApp.
+ *
+ * Since: 1.0
  */
 GPtrArray *
 snapd_snap_get_apps (SnapdSnap *snap)
@@ -114,6 +120,8 @@ snapd_snap_get_apps (SnapdSnap *snap)
  * Get the channel this snap is from, e.g. "stable".
  *
  * Returns: a channel name.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_snap_get_channel (SnapdSnap *snap)
@@ -129,6 +137,8 @@ snapd_snap_get_channel (SnapdSnap *snap)
  * Get the confinement this snap is using, e.g. %SNAPD_CONFINEMENT_STRICT.
  *
  * Returns: a #SnapdConfinement.
+ *
+ * Since: 1.0
  */
 SnapdConfinement
 snapd_snap_get_confinement (SnapdSnap *snap)
@@ -144,6 +154,8 @@ snapd_snap_get_confinement (SnapdSnap *snap)
  * Get the means of contacting the snap developer, e.g. "mailto:developer@example.com".
  *
  * Returns: a contact URL.
+ *
+ * Since: 1.13
  */
 const gchar *
 snapd_snap_get_contact (SnapdSnap *snap)
@@ -159,6 +171,8 @@ snapd_snap_get_contact (SnapdSnap *snap)
  * Get a multi-line description of this snap.
  *
  * Returns: description text.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_snap_get_description (SnapdSnap *snap)
@@ -174,6 +188,8 @@ snapd_snap_get_description (SnapdSnap *snap)
  * Get the developer who created this snap.
  *
  * Returns: a developer name.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_snap_get_developer (SnapdSnap *snap)
@@ -189,6 +205,8 @@ snapd_snap_get_developer (SnapdSnap *snap)
  * Get if this snap is running in developmer mode.
  *
  * Returns: %TRUE if this snap is running in devmode.
+ *
+ * Since: 1.0
  */
 gboolean
 snapd_snap_get_devmode (SnapdSnap *snap)
@@ -204,6 +222,8 @@ snapd_snap_get_devmode (SnapdSnap *snap)
  * Get the download size of this snap or 0 if unknown.
  *
  * Returns: a byte count.
+ *
+ * Since: 1.0
  */
 gint64
 snapd_snap_get_download_size (SnapdSnap *snap)
@@ -220,6 +240,8 @@ snapd_snap_get_download_size (SnapdSnap *snap)
  * from snapd directly.
  *
  * Returns: a URL or path.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_snap_get_icon (SnapdSnap *snap)
@@ -235,6 +257,8 @@ snapd_snap_get_icon (SnapdSnap *snap)
  * Gets the unique ID for this snap.
  *
  * Returns: an ID.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_snap_get_id (SnapdSnap *snap)
@@ -250,6 +274,8 @@ snapd_snap_get_id (SnapdSnap *snap)
  * Get the date this snap was installed or %NULL if unknown.
  *
  * Returns: (transfer none) (allow-none): a #GDateTime or %NULL.
+ *
+ * Since: 1.0
  */
 GDateTime *
 snapd_snap_get_install_date (SnapdSnap *snap)
@@ -265,6 +291,8 @@ snapd_snap_get_install_date (SnapdSnap *snap)
  * Get the installed size of this snap or 0 if unknown.
  *
  * Returns: a byte count.
+ *
+ * Since: 1.0
  */
 gint64
 snapd_snap_get_installed_size (SnapdSnap *snap)
@@ -280,6 +308,8 @@ snapd_snap_get_installed_size (SnapdSnap *snap)
  * Get if this snap is running in enforced confinement (jail) mode.
  *
  * Returns: %TRUE if this snap is running in jailmode.
+ *
+ * Since: 1.8
  */
 gboolean
 snapd_snap_get_jailmode (SnapdSnap *snap)
@@ -288,6 +318,40 @@ snapd_snap_get_jailmode (SnapdSnap *snap)
     return snap->jailmode;
 }
 
+/**
+ * snapd_snap_get_license:
+ * @snap: a #SnapdSnap.
+ *
+ * Gets the SPDX license expression for this snap, e.g. "GPL-3.0+".
+ *
+ * Returns: (allow-none): an SPDX license expression or %NULL.
+ *
+ * Since: 1.19
+ */
+const gchar *
+snapd_snap_get_license (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->license;
+}
+
+/**
+ * snapd_snap_get_title:
+ * @snap: a #SnapdSnap.
+ *
+ * Get the title for this snap. If not available use the snap name instead.
+ *
+ * Returns: (allow-none): a title or %NULL.
+ *
+ * Since: 1.14
+ */
+const gchar *
+snapd_snap_get_title (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->title;
+}
+
 /**
  * snapd_snap_get_name:
  * @snap: a #SnapdSnap.
@@ -296,6 +360,8 @@ snapd_snap_get_jailmode (SnapdSnap *snap)
  * installing / removing.
  *
  * Returns: a name.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_snap_get_name (SnapdSnap *snap)
@@ -311,6 +377,8 @@ snapd_snap_get_name (SnapdSnap *snap)
  * Get the prices that this snap can be purchased at.
  *
  * Returns: (transfer none) (element-type SnapdPrice): an array of #SnapdPrice.
+ *
+ * Since: 1.0
  */
 GPtrArray *
 snapd_snap_get_prices (SnapdSnap *snap)
@@ -326,6 +394,8 @@ snapd_snap_get_prices (SnapdSnap *snap)
  * Get if this snap is only available to the developer.
  *
  * Returns: %TRUE if this is a private snap.
+ *
+ * Since: 1.0
  */
 gboolean
 snapd_snap_get_private (SnapdSnap *snap)
@@ -342,6 +412,8 @@ snapd_snap_get_private (SnapdSnap *snap)
  * See also snapd_snap_get_version().
  *
  * Returns: a revision string.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_snap_get_revision (SnapdSnap *snap)
@@ -357,6 +429,8 @@ snapd_snap_get_revision (SnapdSnap *snap)
  * Get the screenshots that are available for this snap.
  *
  * Returns: (transfer none) (element-type SnapdScreenshot): an array of #SnapdScreenshot.
+ *
+ * Since: 1.0
  */
 GPtrArray *
 snapd_snap_get_screenshots (SnapdSnap *snap)
@@ -372,6 +446,8 @@ snapd_snap_get_screenshots (SnapdSnap *snap)
  * Get the type of snap, e.g. %SNAPD_SNAP_TYPE_APP
  *
  * Returns: a #SnapdSnapType.
+ *
+ * Since: 1.0
  */
 SnapdSnapType
 snapd_snap_get_snap_type (SnapdSnap *snap)
@@ -387,6 +463,8 @@ snapd_snap_get_snap_type (SnapdSnap *snap)
  * Get the current status of this snap, e.g. SNAPD_SNAP_STATUS_INSTALLED.
  *
  * Returns: a #SnapdSnapStatus.
+ *
+ * Since: 1.0
  */
 SnapdSnapStatus
 snapd_snap_get_status (SnapdSnap *snap)
@@ -402,6 +480,8 @@ snapd_snap_get_status (SnapdSnap *snap)
  * Get a single line summary for this snap, e.g. "Best app ever!".
  *
  * Returns: a summary string.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_snap_get_summary (SnapdSnap *snap)
@@ -417,6 +497,8 @@ snapd_snap_get_summary (SnapdSnap *snap)
  * Get the channel that updates will be installed from, e.g. "stable".
  *
  * Returns: a channel name.
+ *
+ * Since: 1.7
  */
 const gchar *
 snapd_snap_get_tracking_channel (SnapdSnap *snap)
@@ -433,6 +515,8 @@ snapd_snap_get_tracking_channel (SnapdSnap *snap)
  * directly modified).
  *
  * Returns: %TRUE if using trymode.
+ *
+ * Since: 1.0
  */
 gboolean
 snapd_snap_get_trymode (SnapdSnap *snap)
@@ -449,6 +533,8 @@ snapd_snap_get_trymode (SnapdSnap *snap)
  * See also snapd_snap_get_revision().
  *
  * Returns: a version string.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_snap_get_version (SnapdSnap *snap)
@@ -512,6 +598,10 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
     case PROP_JAILMODE:
         snap->jailmode = g_value_get_boolean (value);
         break;
+    case PROP_TITLE:
+        g_free (snap->title);
+        snap->title = g_strdup (g_value_get_string (value));
+        break;
     case PROP_NAME:
         g_free (snap->name);
         snap->name = g_strdup (g_value_get_string (value));
@@ -554,6 +644,10 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
         g_free (snap->version);
         snap->version = g_strdup (g_value_get_string (value));
         break;
+    case PROP_LICENSE:
+        g_free (snap->license);
+        snap->license = g_strdup (g_value_get_string (value));
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -605,6 +699,9 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_JAILMODE:
         g_value_set_boolean (value, snap->jailmode);
         break;
+    case PROP_TITLE:
+        g_value_set_string (value, snap->title);
+        break;
     case PROP_NAME:
         g_value_set_string (value, snap->name);
         break;
@@ -638,6 +735,9 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_VERSION:
         g_value_set_string (value, snap->version);
         break;
+    case PROP_LICENSE:
+        g_value_set_string (value, snap->license);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -649,8 +749,7 @@ snapd_snap_finalize (GObject *object)
 {
     SnapdSnap *snap = SNAPD_SNAP (object);
 
-    if (snap->apps != NULL)
-        g_clear_pointer (&snap->apps, g_ptr_array_unref);
+    g_clear_pointer (&snap->apps, g_ptr_array_unref);
     g_clear_pointer (&snap->channel, g_free);
     g_clear_pointer (&snap->contact, g_free);
     g_clear_pointer (&snap->description, g_free);
@@ -659,12 +758,12 @@ snapd_snap_finalize (GObject *object)
     g_clear_pointer (&snap->id, g_free);
     g_clear_pointer (&snap->install_date, g_date_time_unref);
     g_clear_pointer (&snap->name, g_free);
-    if (snap->prices != NULL)
-        g_clear_pointer (&snap->prices, g_ptr_array_unref);
+    g_clear_pointer (&snap->license, g_free);
+    g_clear_pointer (&snap->prices, g_ptr_array_unref);
     g_clear_pointer (&snap->revision, g_free);
-    if (snap->screenshots != NULL)
-        g_clear_pointer (&snap->screenshots, g_ptr_array_unref);
+    g_clear_pointer (&snap->screenshots, g_ptr_array_unref);
     g_clear_pointer (&snap->summary, g_free);
+    g_clear_pointer (&snap->title, g_free);
     g_clear_pointer (&snap->tracking_channel, g_free);
     g_clear_pointer (&snap->version, g_free);
 }
@@ -769,6 +868,20 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                            "TRUE if the snap is currently installed in jailmode",
                                                            FALSE,
                                                            G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_LICENSE,
+                                     g_param_spec_string ("license",
+                                                          "license",
+                                                          "The snap license as an SPDX expression",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_TITLE,
+                                     g_param_spec_string ("title",
+                                                          "title",
+                                                          "The snap title",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_NAME,
                                      g_param_spec_string ("name",
