@@ -10,6 +10,7 @@
 #include "config.h"
 
 #include "snapd-system-information.h"
+#include "snapd-enum-types.h"
 
 /**
  * SECTION:snapd-system-information
@@ -25,6 +26,8 @@
  *
  * #SnapdSystemInformation is an opaque data structure and can only be accessed
  * using the provided functions.
+ *
+ * Since: 1.0
  */
 
 struct _SnapdSystemInformation
@@ -32,6 +35,7 @@ struct _SnapdSystemInformation
     GObject parent_instance;
 
     gchar *binaries_directory;
+    SnapdSystemConfinement confinement;
     gchar *kernel_version;
     gboolean on_classic;
     gboolean managed;
@@ -55,6 +59,7 @@ enum
     PROP_KERNEL_VERSION,
     PROP_BINARIES_DIRECTORY,
     PROP_MOUNT_DIRECTORY,
+    PROP_CONFINEMENT,
     PROP_LAST
 };
 
@@ -67,6 +72,8 @@ G_DEFINE_TYPE (SnapdSystemInformation, snapd_system_information, G_TYPE_OBJECT)
  * Get the directory snap binaries are stored, e.g. "/snap/bin".
  *
  * Returns: a directory.
+ *
+ * Since: 1.11
  */
 const gchar *
 snapd_system_information_get_binaries_directory (SnapdSystemInformation *system_information)
@@ -75,6 +82,23 @@ snapd_system_information_get_binaries_directory (SnapdSystemInformation *system_
     return system_information->binaries_directory;
 }
 
+/**
+ * snapd_system_information_get_confinement:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Get the level of confinement the system supports, e.g. %SNAPD_SYSTEM_CONFINEMENT_STRICT.
+ *
+ * Returns: a #SnapdSystemConfinement.
+ *
+ * Since: 1.15
+ */
+SnapdSystemConfinement
+snapd_system_information_get_confinement (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), SNAPD_SYSTEM_CONFINEMENT_UNKNOWN);
+    return system_information->confinement;
+}
+
 /**
  * snapd_system_information_get_kernel_version:
  * @system_information: a #SnapdSystemInformation.
@@ -82,6 +106,8 @@ snapd_system_information_get_binaries_directory (SnapdSystemInformation *system_
  * Get the version of the kernel snapd is running on, e.g. "4.10.0-15-generic".
  *
  * Returns: a version string.
+ *
+ * Since: 1.11
  */
 const gchar *
 snapd_system_information_get_kernel_version (SnapdSystemInformation *system_information)
@@ -97,6 +123,8 @@ snapd_system_information_get_kernel_version (SnapdSystemInformation *system_info
  * Get if snapd is running on a managed system.
  *
  * Returns: %TRUE if running on a managed system.
+ *
+ * Since: 1.7
  */
 gboolean
 snapd_system_information_get_managed (SnapdSystemInformation *system_information)
@@ -112,6 +140,8 @@ snapd_system_information_get_managed (SnapdSystemInformation *system_information
  * Get the directory snaps are mounted, e.g. "/snap".
  *
  * Returns: a directory.
+ *
+ * Since: 1.11
  */
 const gchar *
 snapd_system_information_get_mount_directory (SnapdSystemInformation *system_information)
@@ -127,6 +157,8 @@ snapd_system_information_get_mount_directory (SnapdSystemInformation *system_inf
  * Get if this system is a classic system.
  *
  * Returns: %TRUE if running on a classic system.
+ *
+ * Since: 1.0
  */
 gboolean
 snapd_system_information_get_on_classic (SnapdSystemInformation *system_information)
@@ -142,6 +174,8 @@ snapd_system_information_get_on_classic (SnapdSystemInformation *system_informat
  * Get the operating system ID, e.g. "ubuntu".
  *
  * Returns: an operating system ID.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_system_information_get_os_id (SnapdSystemInformation *system_information)
@@ -157,6 +191,8 @@ snapd_system_information_get_os_id (SnapdSystemInformation *system_information)
  * Get the operating system version, e.g. "16.04".
  *
  * Returns: a version string.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_system_information_get_os_version (SnapdSystemInformation *system_information)
@@ -172,6 +208,8 @@ snapd_system_information_get_os_version (SnapdSystemInformation *system_informat
  * Get the series of snapd running, e.g. "16".
  *
  * Returns: a series string.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_system_information_get_series (SnapdSystemInformation *system_information)
@@ -187,6 +225,8 @@ snapd_system_information_get_series (SnapdSystemInformation *system_information)
  * Get the store being used by snapd, e.g. "Ubuntu"
  *
  * Returns: (allow-none): a store id or %NULL.
+ *
+ * Since: 1.7
  */
 const gchar *
 snapd_system_information_get_store (SnapdSystemInformation *system_information)
@@ -202,6 +242,8 @@ snapd_system_information_get_store (SnapdSystemInformation *system_information)
  * Get the version of snapd running, e.g. "2.11+ppa174-1".
  *
  * Returns: a version string.
+ *
+ * Since: 1.0
  */
 const gchar *
 snapd_system_information_get_version (SnapdSystemInformation *system_information)
@@ -220,6 +262,9 @@ snapd_system_information_set_property (GObject *object, guint prop_id, const GVa
         g_free (system_information->binaries_directory);
         system_information->binaries_directory = g_strdup (g_value_get_string (value));
         break;
+    case PROP_CONFINEMENT:
+        system_information->confinement = g_value_get_enum (value);
+        break;
     case PROP_KERNEL_VERSION:
         g_free (system_information->kernel_version);
         system_information->kernel_version = g_strdup (g_value_get_string (value));
@@ -269,6 +314,9 @@ snapd_system_information_get_property (GObject *object, guint prop_id, GValue *v
     case PROP_BINARIES_DIRECTORY:
         g_value_set_string (value, system_information->binaries_directory);
         break;
+    case PROP_CONFINEMENT:
+        g_value_set_enum (value, system_information->confinement);
+        break;
     case PROP_KERNEL_VERSION:
         g_value_set_string (value, system_information->kernel_version);
         break;
@@ -333,6 +381,13 @@ snapd_system_information_class_init (SnapdSystemInformationClass *klass)
                                                           "Directory with snap binaries",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_CONFINEMENT,
+                                     g_param_spec_enum ("confinement",
+                                                        "confinement",
+                                                        "Confinement level supported by system",
+                                                        SNAPD_TYPE_SYSTEM_CONFINEMENT, SNAPD_SYSTEM_CONFINEMENT_UNKNOWN,
+                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_KERNEL_VERSION,
                                      g_param_spec_string ("kernel-version",
