@@ -28,8 +28,27 @@ struct _SnapdSystemInformationClass
     GObjectClass parent_class;
 };
 
+/**
+ * SnapdSystemConfinement:
+ * @SNAPD_SYSTEM_CONFINEMENT_UNKNOWN: the confinement of the system is unknown.
+ * @SNAPD_SYSTEM_CONFINEMENT_STRICT: the system supports strict confinement.
+ * @SNAPD_SYSTEM_CONFINEMENT_PARTIAL: the system supports partial confinement.
+ *
+ * Confinment used by a snap.
+ *
+ * Since: 1.15
+ */
+typedef enum
+{
+    SNAPD_SYSTEM_CONFINEMENT_UNKNOWN,
+    SNAPD_SYSTEM_CONFINEMENT_STRICT,
+    SNAPD_SYSTEM_CONFINEMENT_PARTIAL
+} SnapdSystemConfinement;
+
 const gchar *snapd_system_information_get_binaries_directory (SnapdSystemInformation *system_information);
 
+SnapdSystemConfinement snapd_system_information_get_confinement (SnapdSystemInformation *system_information);
+
 const gchar *snapd_system_information_get_kernel_version     (SnapdSystemInformation *system_information);
 
 gboolean     snapd_system_information_get_managed            (SnapdSystemInformation *system_information);
