@@ -20,7 +20,7 @@ class Q_DECL_EXPORT QSnapdApp : public QSnapdWrappedObject
     Q_PROPERTY(QString name READ name)
     Q_PROPERTY(QStringList aliases READ aliases)
     Q_PROPERTY(QSnapdDaemonType daemonType READ daemonType)
-    Q_ENUMS(QSnapdSnapDaemonType)
+    Q_PROPERTY(QString desktopFile READ desktopFile)
 
 public:
     enum QSnapdDaemonType
@@ -33,11 +33,14 @@ public:
         Dbus,
         Notify
     };
+    Q_ENUM(QSnapdDaemonType)
+
     explicit QSnapdApp (void* snapd_object, QObject* parent = 0);
 
     QString name () const;
     QStringList aliases () const;
     QSnapdDaemonType daemonType () const;
+    QString desktopFile () const;
 };
 
 #endif
