@@ -540,6 +540,9 @@ class QSnapdClientPrivate;
 class Q_DECL_EXPORT QSnapdClient : public QObject
 {
     Q_OBJECT
+
+    Q_PROPERTY(QString userAgent READ userAgent WRITE setUserAgent)
+    Q_PROPERTY(bool allowInteraction READ allowInteraction WRITE setAllowInteraction)
     Q_FLAGS(FindFlags)
 
 public:
@@ -563,7 +566,11 @@ public:
     virtual ~QSnapdClient ();
     Q_INVOKABLE QSnapdConnectRequest *connect ();
     Q_INVOKABLE QSnapdLoginRequest *login (const QString& username, const QString& password);
-    Q_INVOKABLE QSnapdLoginRequest *login (const QString& username, const QString& password, const QString& otp);  
+    Q_INVOKABLE QSnapdLoginRequest *login (const QString& username, const QString& password, const QString& otp);
+    Q_INVOKABLE void setUserAgent (const QString &userAgent);
+    Q_INVOKABLE QString userAgent () const;
+    Q_INVOKABLE void setAllowInteraction (bool allowInteraction);
+    Q_INVOKABLE bool allowInteraction () const;
     Q_INVOKABLE void setAuthData (QSnapdAuthData *authData);
     Q_INVOKABLE QSnapdAuthData *authData ();
     Q_INVOKABLE QSnapdGetSystemInformationRequest *getSystemInformation ();
@@ -586,8 +593,8 @@ public:
     Q_INVOKABLE QSnapdInstallRequest *install (InstallFlags flags, const QString &name, const QString &channel);
     Q_INVOKABLE QSnapdInstallRequest *install (InstallFlags flags, const QString &name, const QString &channel, const QString &revision);
     Q_INVOKABLE QSnapdInstallRequest *install (QIODevice *ioDevice);
-    Q_INVOKABLE QSnapdInstallRequest *install (InstallFlags flags, QIODevice *ioDevice);  
-    Q_INVOKABLE QSnapdTryRequest *trySnap (const QString &path);  
+    Q_INVOKABLE QSnapdInstallRequest *install (InstallFlags flags, QIODevice *ioDevice);
+    Q_INVOKABLE QSnapdTryRequest *trySnap (const QString &path);
     Q_INVOKABLE QSnapdRefreshRequest *refresh (const QString &name);
     Q_INVOKABLE QSnapdRefreshRequest *refresh (const QString &name, const QString &channel);
     Q_INVOKABLE QSnapdRefreshAllRequest *refreshAll ();
