@@ -13,8 +13,8 @@
 #include <QtCore/QObject>
 #include <Snapd/Change>
 
-struct QSnapdRequestPrivate;
-  
+class QSnapdRequestPrivate;
+
 class Q_DECL_EXPORT QSnapdRequest : public QObject
 {
     Q_OBJECT
@@ -23,7 +23,6 @@ class Q_DECL_EXPORT QSnapdRequest : public QObject
     Q_PROPERTY(QSnapdError error READ error)
     Q_PROPERTY(QString errorString READ errorString)
     Q_PROPERTY(QSnapdChange change READ change)
-    Q_ENUMS(QSnapdError)
 
 public:
     enum QSnapdError
@@ -50,8 +49,10 @@ public:
         PasswordPolicyError,
         NeedsDevmode,
         NeedsClassic,
-        NeedsClassicSystem
+        NeedsClassicSystem,
+        Cancelled
     };
+    Q_ENUM(QSnapdError)
 
     explicit QSnapdRequest (void *snapd_client, QObject* parent = 0);
     ~QSnapdRequest ();
@@ -69,7 +70,7 @@ protected:
     void *getCancellable () const;
     void finish (void *error);
 
-signals:
+Q_SIGNALS:
     void progress ();
     void complete ();
 
