@@ -34,6 +34,7 @@ class Q_DECL_EXPORT QSnapdSnap : public QSnapdWrappedObject
     Q_PROPERTY(QDateTime installDate READ installDate)
     Q_PROPERTY(qint64 installedSize READ installedSize)
     Q_PROPERTY(bool jailmode READ jailmode)
+    Q_PROPERTY(QString license READ license)
     Q_PROPERTY(QString name READ name)
     Q_PROPERTY(int priceCount READ priceCount)
     Q_PROPERTY(bool isPrivate READ isPrivate)
@@ -41,10 +42,10 @@ class Q_DECL_EXPORT QSnapdSnap : public QSnapdWrappedObject
     Q_PROPERTY(QSnapdSnapType snapType READ snapType)
     Q_PROPERTY(QSnapdSnapStatus status READ status)
     Q_PROPERTY(QString summary READ summary)
+    Q_PROPERTY(QString title READ title)
     Q_PROPERTY(QString trackingChannel READ trackingChannel)
     Q_PROPERTY(bool trymode READ trymode)
     Q_PROPERTY(QString version READ version)
-    Q_ENUMS(QSnapdConfinement QSnapdSnapType QSnapdSnapStatus)
 
 public:
     enum QSnapdConfinement
@@ -54,6 +55,8 @@ public:
         Devmode,
         Classic
     };
+    Q_ENUM(QSnapdConfinement)
+
     enum QSnapdSnapType
     {
         TypeUnknown,
@@ -62,6 +65,8 @@ public:
         Gadget,
         OperatingSystem
     };
+    Q_ENUM(QSnapdSnapType)
+
     enum QSnapdSnapStatus
     {
         StatusUnknown,
@@ -70,6 +75,7 @@ public:
         Installed,
         Active
     };
+    Q_ENUM(QSnapdSnapStatus)
 
     explicit QSnapdSnap (void* snapd_object, QObject* parent = 0);
 
@@ -87,6 +93,7 @@ public:
     QDateTime installDate () const;
     qint64 installedSize () const;
     bool jailmode () const;
+    QString license () const;
     QString name () const;
     int priceCount () const;
     Q_INVOKABLE QSnapdPrice *price (int) const;
@@ -97,9 +104,10 @@ public:
     QSnapdSnapType snapType () const;
     QSnapdSnapStatus status () const;
     QString summary () const;
+    QString title () const;
     QString trackingChannel () const;
     bool trymode () const;
-    QString version () const; 
+    QString version () const;
 };
 
 #endif
