@@ -12,8 +12,9 @@
 #include "Snapd/client.h"
 #include "client-private.h"
 
-struct QSnapdClientPrivate
+class QSnapdClientPrivate
 {
+public:
     QSnapdClientPrivate ()
     {
         client = snapd_client_new ();
@@ -85,12 +86,37 @@ QSnapdLoginRequest *QSnapdClient::login (const QString& username, const QString&
     return new QSnapdLoginRequest (d->client, username, password, otp);
 }
 
+void QSnapdClient::setUserAgent (const QString &userAgent)
+{
+    Q_D(QSnapdClient);
+    snapd_client_set_user_agent (d->client, userAgent.isNull () ? NULL : userAgent.toStdString ().c_str ());
+}
+
+QString QSnapdClient::userAgent () const
+{
+    Q_D(const QSnapdClient);
+    return snapd_client_get_user_agent (d->client);
+}
+
+void QSnapdClient::setAllowInteraction (bool allowInteraction)
+{
+    Q_D(QSnapdClient);
+    snapd_client_set_allow_interaction (d->client, allowInteraction);
+}
+
+bool QSnapdClient::allowInteraction () const
+{
+    Q_D(const QSnapdClient);
+    return snapd_client_get_allow_interaction (d->client);
+}
+
 void QSnapdClient::setAuthData (QSnapdAuthData *authData)
 {
     Q_D(QSnapdClient);
     snapd_client_set_auth_data (d->client, SNAPD_AUTH_DATA (authData->wrappedObject ()));
 }
 
+// NOTE: This should be const but we can't do that without breaking ABI..
 QSnapdAuthData *QSnapdClient::authData ()
 {
     Q_D(QSnapdClient);
@@ -454,8 +480,6 @@ void QSnapdConnectRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_connect_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -494,8 +518,6 @@ void QSnapdLoginRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     auth_data = snapd_client_login_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdLoginRequest);
     d->auth_data = (SnapdAuthData*) g_steal_pointer (&auth_data);
@@ -541,8 +563,6 @@ void QSnapdGetSystemInformationRequest::handleResult (void *object, void *result
     g_autoptr(GError) error = NULL;
 
     info = snapd_client_get_system_information_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdGetSystemInformationRequest);
     d->info = (SnapdSystemInformation*) g_steal_pointer (&info);
@@ -584,8 +604,6 @@ void QSnapdListRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snaps = snapd_client_list_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdListRequest);
     d->snaps = (GPtrArray*) g_steal_pointer (&snaps);
@@ -635,8 +653,6 @@ void QSnapdListOneRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snap = snapd_client_list_one_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdListOneRequest);
     d->snap = (SnapdSnap*) g_steal_pointer (&snap);
@@ -679,8 +695,6 @@ void QSnapdGetIconRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     icon = snapd_client_get_icon_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdGetIconRequest);
     d->icon = (SnapdIcon*) g_steal_pointer (&icon);
@@ -723,8 +737,6 @@ void QSnapdGetAssertionsRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     assertions = snapd_client_get_assertions_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdGetAssertionsRequest);
     d->assertions = (gchar **) g_steal_pointer (&assertions);
@@ -784,12 +796,9 @@ void QSnapdAddAssertionsRequest::runSync ()
 
 void QSnapdAddAssertionsRequest::handleResult (void *object, void *result)
 {
-    g_auto(GStrv) assertions = NULL;
     g_autoptr(GError) error = NULL;
 
     snapd_client_add_assertions_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -828,8 +837,6 @@ void QSnapdGetInterfacesRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_get_interfaces_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &plugs, &slots_, &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdGetInterfacesRequest);
     d->plugs = (GPtrArray*) g_steal_pointer (&plugs);
@@ -889,8 +896,6 @@ static void progress_cb (SnapdClient *client, SnapdChange *change, gpointer, gpo
 void QSnapdConnectInterfaceRequest::runSync ()
 {
     Q_D(QSnapdConnectInterfaceRequest);
-    g_autoptr(GPtrArray) plugs = NULL;
-    g_autoptr(GPtrArray) slots_ = NULL;
     g_autoptr(GError) error = NULL;
     snapd_client_connect_interface_sync (SNAPD_CLIENT (getClient ()),
                                          d->plug_snap.toStdString ().c_str (), d->plug_name.toStdString ().c_str (),
@@ -905,8 +910,6 @@ void QSnapdConnectInterfaceRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_connect_interface_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -934,8 +937,6 @@ QSnapdDisconnectInterfaceRequest::QSnapdDisconnectInterfaceRequest (const QStrin
 void QSnapdDisconnectInterfaceRequest::runSync ()
 {
     Q_D(QSnapdDisconnectInterfaceRequest);
-    g_autoptr(GPtrArray) plugs = NULL;
-    g_autoptr(GPtrArray) slots_ = NULL;
     g_autoptr(GError) error = NULL;
     snapd_client_disconnect_interface_sync (SNAPD_CLIENT (getClient ()),
                                             d->plug_snap.toStdString ().c_str (), d->plug_name.toStdString ().c_str (),
@@ -950,8 +951,6 @@ void QSnapdDisconnectInterfaceRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_disconnect_interface_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1005,8 +1004,6 @@ void QSnapdFindRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snaps = snapd_client_find_section_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &suggested_currency, &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdFindRequest);
     d->snaps = (GPtrArray*) g_steal_pointer (&snaps);
@@ -1054,7 +1051,6 @@ void QSnapdFindRefreshableRequest::runSync ()
 {
     Q_D(QSnapdFindRefreshableRequest);
     g_autoptr(GError) error = NULL;
-    g_autofree gchar *suggested_currency = NULL;
     d->snaps = snapd_client_find_refreshable_sync (SNAPD_CLIENT (getClient ()), G_CANCELLABLE (getCancellable ()), &error);
     finish (error);
 }
@@ -1062,12 +1058,9 @@ void QSnapdFindRefreshableRequest::runSync ()
 void QSnapdFindRefreshableRequest::handleResult (void *object, void *result)
 {
     g_autoptr(GPtrArray) snaps = NULL;
-    g_autofree gchar *suggested_currency = NULL;
     g_autoptr(GError) error = NULL;
 
     snaps = snapd_client_find_refreshable_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdFindRefreshableRequest);
     d->snaps = (GPtrArray*) g_steal_pointer (&snaps);
@@ -1151,8 +1144,6 @@ void QSnapdInstallRequest::handleResult (void *object, void *result)
         snapd_client_install2_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
     else
         snapd_client_install_stream_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1202,8 +1193,6 @@ void QSnapdTryRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_try_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1243,8 +1232,6 @@ void QSnapdRefreshRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_refresh_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1284,8 +1271,6 @@ void QSnapdRefreshAllRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snap_names = snapd_client_refresh_all_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdRefreshAllRequest);
     d->snap_names = (gchar **) g_steal_pointer (&snap_names);
@@ -1335,8 +1320,6 @@ void QSnapdRemoveRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_remove_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1376,8 +1359,6 @@ void QSnapdEnableRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_enable_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1417,8 +1398,6 @@ void QSnapdDisableRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_disable_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1457,8 +1436,6 @@ void QSnapdCheckBuyRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     can_buy = snapd_client_check_buy_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdCheckBuyRequest);
     d->canBuy = can_buy;
@@ -1502,8 +1479,6 @@ void QSnapdBuyRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     snapd_client_buy_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1541,8 +1516,6 @@ void QSnapdGetSectionsRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     sections = snapd_client_get_sections_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdGetSectionsRequest);
     d->sections = (gchar**) g_steal_pointer (&sections);
@@ -1589,8 +1562,6 @@ void QSnapdGetAliasesRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     aliases = snapd_client_get_aliases_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     Q_D(QSnapdGetAliasesRequest);
     d->aliases = (GPtrArray*) g_steal_pointer (&aliases);
@@ -1645,8 +1616,6 @@ void QSnapdEnableAliasesRequest::handleResult (void *object, void *result)
 {
     g_autoptr(GError) error = NULL;
     snapd_client_enable_aliases_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1691,8 +1660,6 @@ void QSnapdDisableAliasesRequest::handleResult (void *object, void *result)
 {
     g_autoptr(GError) error = NULL;
     snapd_client_disable_aliases_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1737,8 +1704,6 @@ void QSnapdResetAliasesRequest::handleResult (void *object, void *result)
 {
     g_autoptr(GError) error = NULL;
     snapd_client_reset_aliases_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
@@ -1785,8 +1750,6 @@ void QSnapdRunSnapCtlRequest::handleResult (void *object, void *result)
     Q_D(QSnapdRunSnapCtlRequest);
 
     snapd_client_run_snapctl_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &d->stdout_output, &d->stderr_output, &error);
-    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        return;
 
     finish (error);
 }
