@@ -11,8 +11,9 @@
 
 #include "Snapd/request.h"
 
-struct QSnapdRequestPrivate
+class QSnapdRequestPrivate
 {
+public:
     QSnapdRequestPrivate (void *snapd_client)
     {
         client = SNAPD_CLIENT (g_object_ref (snapd_client));
@@ -140,6 +141,8 @@ void QSnapdRequest::finish (void *error)
                 break;
             }
         }
+        else if (g_error_matches (e, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+            d->error = QSnapdRequest::QSnapdError::Cancelled;
         else
             d->error = QSnapdRequest::QSnapdError::UnknownError;
         d->errorString = e->message;
