@@ -117,6 +117,11 @@ bool QSnapdSnap::jailmode () const
     return snapd_snap_get_jailmode (SNAPD_SNAP (wrapped_object));
 }
 
+QString QSnapdSnap::license () const
+{
+    return snapd_snap_get_license (SNAPD_SNAP (wrapped_object));
+}
+
 QString QSnapdSnap::name () const
 {
     return snapd_snap_get_name (SNAPD_SNAP (wrapped_object));
@@ -209,6 +214,11 @@ QString QSnapdSnap::summary () const
     return snapd_snap_get_summary (SNAPD_SNAP (wrapped_object));
 }
 
+QString QSnapdSnap::title () const
+{
+    return snapd_snap_get_title (SNAPD_SNAP (wrapped_object));
+}
+
 QString QSnapdSnap::trackingChannel () const
 {
     return snapd_snap_get_tracking_channel (SNAPD_SNAP (wrapped_object));
