@@ -48,13 +48,19 @@ struct _MockSnapd
 {
     GObject parent_instance;
 
+    GThread *thread;
+    GMainLoop *loop;
+    GMainContext *context;
+
     GSocket *client_socket;
     GSocket *server_socket;
     GSource *read_source;
     GByteArray *buffer;
     gsize n_read;
+    gboolean close_on_request;
     GList *accounts;
     GList *snaps;
+    gchar *confinement;
     gchar *store;
     gboolean managed;
     gboolean on_classic;
@@ -68,6 +74,7 @@ struct _MockSnapd
     gchar *suggested_currency;
     gchar *spawn_time;
     gchar *ready_time;
+    SoupMessageHeaders *last_request_headers;
 };
 
 G_DEFINE_TYPE (MockSnapd, mock_snapd, G_TYPE_OBJECT)
@@ -76,7 +83,7 @@ static void
 mock_alias_free (MockAlias *alias)
 {
     g_free (alias->name);
-    g_free (alias->status);  
+    g_free (alias->status);
     g_slice_free (MockAlias, alias);
 }
 
@@ -86,6 +93,7 @@ mock_app_free (MockApp *app)
     g_free (app->name);
     g_list_free_full (app->aliases, (GDestroyNotify) mock_alias_free);
     g_free (app->daemon);
+    g_free (app->desktop_file);
     g_slice_free (MockApp, app);
 }
 
@@ -131,14 +139,18 @@ mock_snap_free (MockSnap *snap)
     g_free (snap->description);
     g_free (snap->developer);
     g_free (snap->icon);
+    g_free (snap->icon_mime_type);
+    g_bytes_unref (snap->icon_data);
     g_free (snap->id);
     g_free (snap->install_date);
+    g_free (snap->license);
     g_free (snap->name);
     g_list_free_full (snap->prices, (GDestroyNotify) mock_price_free);
     g_list_free_full (snap->screenshots, (GDestroyNotify) mock_screenshot_free);
     g_free (snap->revision);
     g_free (snap->status);
     g_free (snap->summary);
+    g_free (snap->title);
     g_free (snap->tracking_channel);
     g_free (snap->type);
     g_free (snap->version);
@@ -163,6 +175,30 @@ mock_snapd_get_client_socket (MockSnapd *snapd)
     return snapd->client_socket;
 }
 
+void
+mock_snapd_set_close_on_request (MockSnapd *snapd, gboolean close_on_request)
+{
+    g_return_if_fail (MOCK_IS_SNAPD (snapd));
+    snapd->close_on_request = close_on_request;
+}
+
+void
+mock_snapd_stop (MockSnapd *snapd)
+{
+    g_return_if_fail (MOCK_IS_SNAPD (snapd));
+    g_socket_close (snapd->server_socket, NULL);
+    if (snapd->read_source != NULL)
+        g_source_destroy (snapd->read_source);
+    g_clear_pointer (&snapd->read_source, g_source_unref);
+}
+
+void
+mock_snapd_set_confinement (MockSnapd *snapd, const gchar *confinement)
+{
+    g_free (snapd->confinement);
+    snapd->confinement = g_strdup (confinement);
+}
+
 void
 mock_snapd_set_store (MockSnapd *snapd, const gchar *name)
 {
@@ -179,7 +215,7 @@ mock_snapd_set_managed (MockSnapd *snapd, gboolean managed)
 void
 mock_snapd_set_on_classic (MockSnapd *snapd, gboolean on_classic)
 {
-    snapd->on_classic = on_classic;  
+    snapd->on_classic = on_classic;
 }
 
 void
@@ -227,17 +263,13 @@ mock_snap_new (const gchar *name)
     MockSnap *snap;
 
     snap = g_slice_new0 (MockSnap);
-    snap->channel = g_strdup ("CHANNEL");
     snap->confinement = g_strdup ("strict");
-    snap->contact = g_strdup ("CONTACT");
-    snap->description = g_strdup ("DESCRIPTION");
     snap->developer = g_strdup ("DEVELOPER");
     snap->icon = g_strdup ("ICON");
     snap->id = g_strdup ("ID");
     snap->name = g_strdup (name);
     snap->revision = g_strdup ("REVISION");
     snap->status = g_strdup ("active");
-    snap->summary = g_strdup ("SUMMARY");
     snap->type = g_strdup ("app");
     snap->version = g_strdup ("VERSION");
 
@@ -319,8 +351,6 @@ mock_snapd_add_snap (MockSnapd *snapd, const gchar *name)
     MockSnap *snap;
 
     snap = mock_snap_new (name);
-    snap->installed_size = 65535;
-    snap->install_date = g_strdup ("2017-01-01T00:00:00+12:00");
     snapd->snaps = g_list_append (snapd->snaps, snap);
 
     return snap;
@@ -442,7 +472,14 @@ void
 mock_app_set_daemon (MockApp *app, const gchar *daemon)
 {
     g_free (app->daemon);
-    app->daemon = g_strdup (daemon);  
+    app->daemon = g_strdup (daemon);
+}
+
+void
+mock_app_set_desktop_file (MockApp *app, const gchar *desktop_file)
+{
+    g_free (app->desktop_file);
+    app->desktop_file = g_strdup (desktop_file);
 }
 
 void
@@ -487,6 +524,15 @@ mock_snap_set_icon (MockSnap *snap, const gchar *icon)
     snap->icon = g_strdup (icon);
 }
 
+void
+mock_snap_set_icon_data (MockSnap *snap, const gchar *mime_type, GBytes *data)
+{
+    g_free (snap->icon_mime_type);
+    snap->icon_mime_type = g_strdup (mime_type);
+    g_bytes_unref (snap->icon_data);
+    snap->icon_data = g_bytes_ref (data);
+}
+
 void
 mock_snap_set_id (MockSnap *snap, const gchar *id)
 {
@@ -501,6 +547,13 @@ mock_snap_set_install_date (MockSnap *snap, const gchar *install_date)
     snap->install_date = g_strdup (install_date);
 }
 
+void
+mock_snap_set_license (MockSnap *snap, const gchar *license)
+{
+    g_free (snap->license);
+    snap->license = g_strdup (license);
+}
+
 MockPrice *
 mock_snap_add_price (MockSnap *snap, gdouble amount, const gchar *currency)
 {
@@ -563,6 +616,13 @@ mock_snap_set_summary (MockSnap *snap, const gchar *summary)
     snap->summary = g_strdup (summary);
 }
 
+void
+mock_snap_set_title (MockSnap *snap, const gchar *title)
+{
+    g_free (snap->title);
+    snap->title = g_strdup (title);
+}
+
 void
 mock_snap_set_tracking_channel (MockSnap *snap, const gchar *channel)
 {
@@ -659,7 +719,34 @@ mock_snapd_get_assertions (MockSnapd *snapd)
 {
     return snapd->assertions;
 }
-  
+
+const gchar *
+mock_snapd_get_last_user_agent (MockSnapd *snapd)
+{
+    if (snapd->last_request_headers == NULL)
+        return NULL;
+
+    return soup_message_headers_get_one (snapd->last_request_headers, "User-Agent");
+}
+
+const gchar *
+mock_snapd_get_last_accept_language (MockSnapd *snapd)
+{
+    if (snapd->last_request_headers == NULL)
+        return NULL;
+
+    return soup_message_headers_get_one (snapd->last_request_headers, "Accept-Language");
+}
+
+const gchar *
+mock_snapd_get_last_allow_interaction (MockSnapd *snapd)
+{
+    if (snapd->last_request_headers == NULL)
+        return NULL;
+
+    return soup_message_headers_get_one (snapd->last_request_headers, "X-Allow-Interaction");
+}
+
 static MockChange *
 add_change (MockSnapd *snapd, JsonNode *data)
 {
@@ -721,7 +808,7 @@ mock_task_free (MockTask *task)
     g_free (task->kind);
     g_free (task->summary);
     g_free (task->status);
-    g_free (task->progress_label);  
+    g_free (task->progress_label);
     g_free (task->spawn_time);
     g_free (task->ready_time);
     g_slice_free (MockTask, task);
@@ -765,13 +852,29 @@ read_data (MockSnapd *snapd, gsize size)
     return TRUE;
 }
 
+static void
+write_data (MockSnapd *snapd, const gchar *content, gsize size)
+{
+    gsize total_written = 0;
+
+    while (total_written < size) {
+        gssize n_written;
+        g_autoptr(GError) error = NULL;
+
+        n_written = g_socket_send (snapd->server_socket, content + total_written, size - total_written, NULL, &error);
+        if (n_written < 0) {
+            g_warning ("Failed to write to snapd client: %s", error->message);
+            return;
+        }
+        total_written += n_written;
+    }
+}
+
 static void
 send_response (MockSnapd *snapd, guint status_code, const gchar *reason_phrase, const gchar *content_type, const guint8 *content, gsize content_length)
 {
     g_autoptr(SoupMessageHeaders) headers = NULL;
     g_autoptr(GString) message = NULL;
-    gssize n_written;
-    g_autoptr(GError) error = NULL;
 
     message = g_string_new (NULL);
     g_string_append_printf (message, "HTTP/1.1 %u %s\r\n", status_code, reason_phrase);
@@ -779,10 +882,8 @@ send_response (MockSnapd *snapd, guint status_code, const gchar *reason_phrase,
     g_string_append_printf (message, "Content-Length: %zi\r\n", content_length);
     g_string_append (message, "\r\n");
 
-    n_written = g_socket_send (snapd->server_socket, message->str, message->len, NULL, &error);
-    g_assert (n_written == message->len);
-    n_written = g_socket_send (snapd->server_socket, (const gchar *) content, content_length, NULL, &error);
-    g_assert (n_written == content_length);
+    write_data (snapd, message->str, message->len);
+    write_data (snapd, (const gchar *) content, content_length);
 }
 
 static void
@@ -904,6 +1005,10 @@ handle_system_info (MockSnapd *snapd, const gchar *method)
 
     builder = json_builder_new ();
     json_builder_begin_object (builder);
+    if (snapd->confinement) {
+        json_builder_set_member_name (builder, "confinement");
+        json_builder_add_string_value (builder, snapd->confinement);
+    }
     json_builder_set_member_name (builder, "os-release");
     json_builder_begin_object (builder);
     json_builder_set_member_name (builder, "id");
@@ -1064,7 +1169,7 @@ get_json (SoupMessageHeaders *headers, SoupMessageBody *body)
 
     parser = json_parser_new ();
     if (!json_parser_load_from_data (parser, body->data, body->length, &error)) {
-        g_warning ("Failed to parse request: %s", error->message);      
+        g_warning ("Failed to parse request: %s", error->message);
         return NULL;
     }
 
@@ -1160,6 +1265,10 @@ make_snap_node (MockSnap *snap)
                 json_builder_set_member_name (builder, "daemon");
                 json_builder_add_string_value (builder, app->daemon);
             }
+            if (app->desktop_file != NULL) {
+                json_builder_set_member_name (builder, "desktop-file");
+                json_builder_add_string_value (builder, app->desktop_file);
+            }
             json_builder_end_object (builder);
         }
         json_builder_end_array (builder);
@@ -1199,7 +1308,11 @@ make_snap_node (MockSnap *snap)
         json_builder_add_int_value (builder, snap->installed_size);
     }
     json_builder_set_member_name (builder, "jailmode");
-    json_builder_add_boolean_value (builder, snap->jailmode);  
+    json_builder_add_boolean_value (builder, snap->jailmode);
+    if (snap->license) {
+        json_builder_set_member_name (builder, "license");
+        json_builder_add_string_value (builder, snap->license);
+    }
     json_builder_set_member_name (builder, "name");
     json_builder_add_string_value (builder, snap->name);
     if (snap->prices != NULL) {
@@ -1251,6 +1364,10 @@ make_snap_node (MockSnap *snap)
         json_builder_set_member_name (builder, "summary");
         json_builder_add_string_value (builder, snap->summary);
     }
+    if (snap->title) {
+        json_builder_set_member_name (builder, "title");
+        json_builder_add_string_value (builder, snap->title);
+    }
     if (snap->tracking_channel) {
         json_builder_set_member_name (builder, "tracking-channel");
         json_builder_add_string_value (builder, snap->tracking_channel);
@@ -1334,7 +1451,7 @@ handle_snaps (MockSnapd *snapd, const gchar *method, SoupMessageHeaders *headers
                 json_builder_add_string_value (builder, snap->name);
             }
             json_builder_end_array (builder);
-            json_builder_end_object (builder);          
+            json_builder_end_object (builder);
 
             change = add_change (snapd, json_builder_get_root (builder));
             send_async_response (snapd, 202, "Accepted", change->id);
@@ -1629,10 +1746,14 @@ handle_icon (MockSnapd *snapd, const gchar *method, const gchar *path)
     name = g_strndup (path, strlen (path) - strlen ("/icon"));
 
     snap = mock_snapd_find_snap (snapd, name);
-    if (snap != NULL)
-        send_response (snapd, 200, "OK", "image/png", (const guint8 *) "ICON", 4);
-    else
+    if (snap == NULL)
         send_error_not_found (snapd, "cannot find snap");
+    else if (snap->icon_data == NULL)
+        send_error_not_found (snapd, "not found");
+    else
+        send_response (snapd, 200, "OK", snap->icon_mime_type,
+                       (const guint8 *) g_bytes_get_data (snap->icon_data, NULL),
+                       g_bytes_get_size (snap->icon_data));
 }
 
 static void
@@ -1915,7 +2036,7 @@ handle_changes (MockSnapd *snapd, const gchar *method, const gchar *change_id)
     json_builder_begin_array (builder);
     for (link = change->tasks; link; link = link->next) {
         MockTask *task = link->data;
-        json_builder_begin_object (builder);  
+        json_builder_begin_object (builder);
         json_builder_set_member_name (builder, "id");
         json_builder_add_string_value (builder, task->id);
         json_builder_set_member_name (builder, "kind");
@@ -1981,7 +2102,7 @@ in_section (MockSnap *snap, const gchar *section)
     if (section == NULL)
         return TRUE;
 
-    for (link = snap->store_sections; link; link = link->next) 
+    for (link = snap->store_sections; link; link = link->next)
         if (strcmp (link->data, section) == 0)
             return TRUE;
 
@@ -1995,7 +2116,7 @@ handle_find (MockSnapd *snapd, const gchar *method, SoupMessageHeaders *headers,
     g_autofree gchar *query_param = NULL;
     g_autofree gchar *name_param = NULL;
     g_autofree gchar *select_param = NULL;
-    g_autofree gchar *section_param = NULL;  
+    g_autofree gchar *section_param = NULL;
     g_autoptr(JsonBuilder) builder = NULL;
     GList *snaps, *link;
 
@@ -2085,6 +2206,10 @@ handle_find (MockSnapd *snapd, const gchar *method, SoupMessageHeaders *headers,
     else
         snaps = snapd->store_snaps;
 
+    /* Make a special query that never responds */
+    if (g_strcmp0 (query_param, "do-not-respond") == 0)
+        return;
+
     builder = json_builder_new ();
     json_builder_begin_array (builder);
     for (link = snaps; link; link = link->next) {
@@ -2251,7 +2376,7 @@ handle_aliases (MockSnapd *snapd, const gchar *method, SoupMessageHeaders *heade
                     json_builder_end_object (builder);
                 }
             }
-          
+
             if (alias_count > 0)
                 json_builder_end_object (builder);
         }
@@ -2335,7 +2460,7 @@ handle_snapctl (MockSnapd *snapd, const gchar *method, SoupMessageHeaders *heade
         return;
     }
 
-    o = json_node_get_object (request);  
+    o = json_node_get_object (request);
     context_id = json_object_get_string_member (o, "context-id");
     args = json_object_get_array_member (o, "args");
 
@@ -2343,7 +2468,7 @@ handle_snapctl (MockSnapd *snapd, const gchar *method, SoupMessageHeaders *heade
     g_string_append_printf (stdout_text, ":%s", context_id);
     for (i = 0; i < json_array_get_length (args); i++) {
         const gchar *arg = json_array_get_string_element (args, i);
-        g_string_append_printf (stdout_text, ":%s", arg);        
+        g_string_append_printf (stdout_text, ":%s", arg);
     }
 
     builder = json_builder_new ();
@@ -2360,6 +2485,9 @@ handle_snapctl (MockSnapd *snapd, const gchar *method, SoupMessageHeaders *heade
 static void
 handle_request (MockSnapd *snapd, const gchar *method, const gchar *path, SoupMessageHeaders *headers, SoupMessageBody *body)
 {
+    g_clear_pointer (&snapd->last_request_headers, soup_message_headers_free);
+    snapd->last_request_headers = g_boxed_copy (SOUP_TYPE_MESSAGE_HEADERS, headers);
+
     if (strcmp (path, "/v2/system-info") == 0)
         handle_system_info (snapd, method);
     else if (strcmp (path, "/v2/login") == 0)
@@ -2437,6 +2565,11 @@ read_cb (GSocket *socket, GIOCondition condition, MockSnapd *snapd)
         soup_message_body_append (body, SOUP_MEMORY_COPY, body_data, content_length);
         buffer = soup_message_body_flatten (body);
 
+        if (snapd->close_on_request) {
+            g_socket_close (socket, NULL);
+            return G_SOURCE_REMOVE;
+        }
+
         handle_request (snapd, method, path, headers, body);
 
         /* Move remaining data to the start of the buffer */
@@ -2447,11 +2580,28 @@ read_cb (GSocket *socket, GIOCondition condition, MockSnapd *snapd)
     return G_SOURCE_CONTINUE;
 }
 
+static gboolean
+mock_snapd_thread_quit (gpointer user_data)
+{
+    MockSnapd *snapd = MOCK_SNAPD (user_data);
+
+    g_main_loop_quit (snapd->loop);
+
+    return FALSE;
+}
+
 static void
 mock_snapd_finalize (GObject *object)
 {
     MockSnapd *snapd = MOCK_SNAPD (object);
 
+    g_main_context_invoke (snapd->context,
+                           mock_snapd_thread_quit,
+                           snapd);
+
+    g_thread_join (snapd->thread);
+    snapd->thread = NULL;
+
     g_clear_object (&snapd->client_socket);
     g_clear_object (&snapd->server_socket);
     if (snapd->read_source != NULL)
@@ -2461,6 +2611,7 @@ mock_snapd_finalize (GObject *object)
     g_list_free_full (snapd->accounts, (GDestroyNotify) mock_account_free);
     g_list_free_full (snapd->snaps, (GDestroyNotify) mock_snap_free);
     snapd->snaps = NULL;
+    g_free (snapd->confinement);
     g_free (snapd->store);
     g_list_free_full (snapd->store_sections, g_free);
     snapd->store_sections = NULL;
@@ -2476,7 +2627,10 @@ mock_snapd_finalize (GObject *object)
     snapd->changes = NULL;
     g_clear_pointer (&snapd->suggested_currency, g_free);
     g_clear_pointer (&snapd->spawn_time, g_free);
-    g_clear_pointer (&snapd->ready_time, g_free);  
+    g_clear_pointer (&snapd->ready_time, g_free);
+    g_clear_pointer (&snapd->last_request_headers, soup_message_headers_free);
+    g_clear_pointer (&snapd->context, g_main_context_unref);
+    g_clear_pointer (&snapd->loop, g_main_loop_unref);
 }
 
 static void
@@ -2487,16 +2641,36 @@ mock_snapd_class_init (MockSnapdClass *klass)
     gobject_class->finalize = mock_snapd_finalize;
 }
 
+gpointer
+mock_snapd_init_thread (gpointer user_data)
+{
+    MockSnapd *snapd = MOCK_SNAPD (user_data);
+
+    /* We create & manage the lifecycle of this thread */
+    g_main_context_push_thread_default (snapd->context);
+
+    g_main_loop_run (snapd->loop);
+
+    return NULL;
+}
+
 static void
 mock_snapd_init (MockSnapd *snapd)
 {
     int fds[2];
 
+    snapd->context = g_main_context_new ();
+    snapd->loop = g_main_loop_new (snapd->context, FALSE);
+
     socketpair (AF_UNIX, SOCK_STREAM, 0, fds);
     snapd->client_socket = g_socket_new_from_fd (fds[0], NULL);
     snapd->server_socket = g_socket_new_from_fd (fds[1], NULL);
     snapd->buffer = g_byte_array_new ();
     snapd->read_source = g_socket_create_source (snapd->server_socket, G_IO_IN, NULL);
     g_source_set_callback (snapd->read_source, (GSourceFunc) read_cb, snapd, NULL);
-    g_source_attach (snapd->read_source, NULL);  
+    g_source_attach (snapd->read_source, snapd->context);
+
+    snapd->thread = g_thread_new ("mock_snapd_thread",
+                                  mock_snapd_init_thread,
+                                  snapd);
 }
