@@ -48,10 +48,13 @@ typedef struct
     gboolean devmode;
     int download_size;
     gchar *icon;
+    gchar *icon_mime_type;
+    GBytes *icon_data;
     gchar *id;
     gchar *install_date;
     int installed_size;
     gboolean jailmode;
+    gchar *license;
     gchar *name;
     GList *prices;
     gboolean is_private;
@@ -59,6 +62,7 @@ typedef struct
     GList *screenshots;
     gchar *status;
     gchar *summary;
+    gchar *title;
     gchar *tracking_channel;
     gboolean trymode;
     gchar *type;
@@ -77,6 +81,7 @@ typedef struct
     gchar *name;
     GList *aliases;
     gchar *daemon;
+    gchar *desktop_file;
 } MockApp;
 
 typedef struct
@@ -123,6 +128,14 @@ MockSnapd      *mock_snapd_new                    (void);
 
 GSocket        *mock_snapd_get_client_socket      (MockSnapd     *snapd);
 
+void            mock_snapd_set_close_on_request   (MockSnapd     *snapd,
+                                                   gboolean       close_on_request);
+
+void            mock_snapd_stop                   (MockSnapd     *snapd);
+
+void            mock_snapd_set_confinement        (MockSnapd     *snapd,
+                                                   const gchar   *confinement);
+
 void            mock_snapd_set_store              (MockSnapd     *snapd,
                                                    const gchar   *name);
 
@@ -176,12 +189,18 @@ void            mock_alias_set_status             (MockAlias     *alias,
 void            mock_app_set_daemon               (MockApp       *app,
                                                    const gchar   *daemon);
 
+void            mock_app_set_desktop_file         (MockApp       *app,
+                                                   const gchar   *desktop_file);
+
 void            mock_snap_set_channel             (MockSnap      *snap,
                                                    const gchar   *channel);
 
 void            mock_snap_set_confinement         (MockSnap      *snap,
                                                    const gchar   *confinement);
 
+void            mock_snap_set_contact             (MockSnap      *snap,
+                                                   const gchar   *contact);
+
 void            mock_snap_set_description         (MockSnap      *snap,
                                                    const gchar   *description);
 
@@ -191,12 +210,19 @@ void            mock_snap_set_developer           (MockSnap      *snap,
 void            mock_snap_set_icon                (MockSnap      *snap,
                                                    const gchar   *icon);
 
+void            mock_snap_set_icon_data           (MockSnap      *snap,
+                                                   const gchar   *mime_type,
+                                                   GBytes        *data);
+
 void            mock_snap_set_id                  (MockSnap      *snap,
                                                    const gchar   *id);
 
 void            mock_snap_set_install_date        (MockSnap      *snap,
                                                    const gchar   *install_date);
 
+void            mock_snap_set_license             (MockSnap      *snap,
+                                                   const gchar   *license);
+
 MockPrice      *mock_snap_add_price               (MockSnap      *snap,
                                                    gdouble        amount,
                                                    const gchar   *currency);
@@ -215,6 +241,9 @@ void            mock_snap_set_status              (MockSnap      *snap,
 void            mock_snap_set_summary             (MockSnap      *snap,
                                                    const gchar   *summary);
 
+void            mock_snap_set_title               (MockSnap      *snap,
+                                                   const gchar   *title);
+
 void            mock_snap_set_tracking_channel    (MockSnap      *snap,
                                                    const gchar   *channel);
 
@@ -238,6 +267,12 @@ void            mock_snapd_add_assertion          (MockSnapd     *snapd,
 
 GList          *mock_snapd_get_assertions         (MockSnapd     *snapd);
 
+const gchar    *mock_snapd_get_last_user_agent    (MockSnapd     *snapd);
+
+const gchar    *mock_snapd_get_last_accept_language (MockSnapd     *snapd);
+
+const gchar    *mock_snapd_get_last_allow_interaction (MockSnapd *snapd);
+
 G_END_DECLS
 
 #endif /* __MOCK_SNAPD_H__ */
